@@ -1,3 +1,3 @@
-from .annotator import Annotator
+from .annotator import Annotator, BatchAnnotator
 from .assistant import AnnotatorAssistant
 from .session import Session
\ No newline at end of file
